;rbsp_efw_spinfit_vxb_subtract_crib.pro
;
;Create the vxb subtracted spinfit data (now from E12 data only)
;
;By Aaron W Breneman
;University of Minnesota
;2013-04-16



pro rbsp_efw_spinfit_vxb_subtract_crib,probe,no_spice_load=no_spice_load,noplot=noplot


;Get the time range if it hasn't already been set
	x = timerange()
	date = strmid(time_string(x[0]),0,10)

	rbspx = 'rbsp'+probe


;Load spice stuff

	if ~keyword_set(no_spice_load) then rbsp_load_spice_kernels

	;Get antenna pointing direction and stuff
	rbsp_load_state,probe=probe,/no_spice_load,datatype=['spinper','spinphase','mat_dsc','Lvec'] 

	rbsp_efw_position_velocity_crib,/no_spice_load,/noplot


;Load eclipse times 

	if ~keyword_set(noplot) then begin
		rbsp_load_eclipse_predict,probe,date
		get_data,'rbsp'+probe+'_umbra',data=eu
		get_data,'rbsp'+probe+'_penumbra',data=ep
	endif

;Load waveform data
	rbsp_load_efw_waveform, probe=probe, datatype = 'esvy', coord = 'uvw',/noclean
	
		
		
;Spinfit data and transform to MGSE coordinates
	rbsp_spinfit, rbspx + '_efw_esvy', plane_dim = 0 ; V12
	rbsp_cotrans, rbspx + '_efw_esvy_spinfit', rbspx + '_sfit12_mgse', /dsc2mgse



;;	;Find the co-rotation Efield
;;	rbsp_corotation_efield,probe,date,/no_spice_load
;;
;;	;Remove corotation Efield
;;	dif_data,rbspx+'_efw_esvy_mgse',rbspx+'_E_coro_mgse',newname=rbspx+'_efw_esvy_mgse'
;

;Apply crude antenna effective length correction to y and z MGSE values
	get_data, rbspx + '_sfit12_mgse', data = d
	d.y[*, 1] *= 1.05d
	d.y[*, 2] *= 1.05d
	store_data, rbspx + '_sfit12_mgse', data = d



;Load the mag data	
	rbsp_load_emfisis,probe=probe,/quicklook

	get_data,rbspx+'_emfisis_quicklook_Mag',data=dd2
	if ~is_struct(dd2) then begin
		print,'******NO MAG DATA TO LOAD.....rbsp_efw_DCfield_removal_crib.pro*******'
		return
	endif		



;Some of the EMFISIS data extends beyond the day loaded. This messes things up
;later. Remove these data points now. 

	t0 = time_double(date)
	t1 = t0 + 86400.

	ttst = tnames(rbspx+'_emfisis_quicklook_Mag',cnt)
	if cnt eq 1 then time_clip,rbspx+'_emfisis_quicklook_Mag',t0,t1,replace=1,error=error,newname=rbspx+'_emfisis_quicklook_Mag'
	ttst = tnames(rbspx+'_emfisis_quicklook_Magnitude',cnt)
	if cnt eq 1 then time_clip,rbspx+'_emfisis_quicklook_Magnitude',t0,t1,replace=1,error=error,newname=rbspx+'_emfisis_quicklook_Magnitude'




;Create the dlimits structure for the EMFISIS quantity. Jianbao's spinfit program needs
;to see that the coords are 'uvw'
	get_data,rbspx +'_emfisis_quicklook_Mag',data=datt
	data_att = {coord_sys:'uvw'}
	dlim = {data_att:data_att}
	store_data,rbspx +'_emfisis_quicklook_Mag',data=datt,dlimits=dlim


;spinfit the mag data and transform to MGSE
	rbsp_decimate,rbspx +'_emfisis_quicklook_Mag', upper = 2
	rbsp_spinfit,rbspx +'_emfisis_quicklook_Mag', plane_dim = 0
	rbsp_cotrans,rbspx +'_emfisis_quicklook_Mag_spinfit', rbspx + '_mag_mgse_spinfit', /dsc2mgse




;vxB subtract the Efield data

	rbsp_vxb_subtract,rbspx+'_state_vel_mgse',rbspx + '_mag_mgse_spinfit',rbspx+'_sfit12_mgse'

	store_data,'Esvy_mgse_vxb_removed',newname=rbspx+'_efw_esvy_mgse_vxb_removed_spinfit'

	split_vec,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit'
	ylim,[rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_y',rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_z'],-5,5

	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_?','ysubtitle',''

	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_x','ytitle','Ex MGSE!C(E-V!Dsc!NxB)!Cspinfit!C[mV/m]'
	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_y','ytitle','Ey MGSE!C(E-V!Dsc!NxB)!Cspinfit!C[mV/m]'
	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_z','ytitle','Ez MGSE!C(E-V!Dsc!NxB)!Cspinfit!C[mV/m]'

	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_x','colors',4
	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_y','colors',1
	options,rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_z','colors',2



	if ~keyword_set(noplot) then begin
		tplot,[rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_y',rbspx+'_efw_esvy_mgse_vxb_removed_spinfit_z']

		if is_struct(eu) then timebar,eu.x,color=50
		if is_struct(eu) then timebar,eu.x + eu.y,color=50
		if is_struct(ep) then timebar,ep.x,color=80
		if is_struct(ep) then timebar,ep.x + ep.y,color=80
	endif


end

